@@ -5,8 +5,8 @@
 #include "panel-applet-enums.h"
 
 
-/* enumerations from "/usr/src/ports/gnome-panel/gnome-panel-3.14.0-1.i686/src/gnome-panel-3.14.0/libpanel-applet/panel-applet.h" */
-#include "/usr/src/ports/gnome-panel/gnome-panel-3.14.0-1.i686/src/gnome-panel-3.14.0/libpanel-applet/panel-applet.h"
+/* enumerations from "/usr/src/ports/gnome-panel/gnome-panel-3.18.1-1.x86_64/src/gnome-panel-3.18.1/libpanel-applet/panel-applet.h" */
+#include "/usr/src/ports/gnome-panel/gnome-panel-3.18.1-1.x86_64/src/gnome-panel-3.18.1/libpanel-applet/panel-applet.h"
 static const GEnumValue _panel_applet_orient_values[] = {
   { PANEL_APPLET_ORIENT_UP, "PANEL_APPLET_ORIENT_UP", "up" },
   { PANEL_APPLET_ORIENT_DOWN, "PANEL_APPLET_ORIENT_DOWN", "down" },
